package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.bo.request.RaiseOrderRequestBO;
import com.huiju.estateagents.bo.request.RaiseRecordRequestBO;
import com.huiju.estateagents.entity.TaRaiseRecord;
import com.huiju.estateagents.mapper.TaRaiseRecordMapper;
import com.huiju.estateagents.service.ITaRaiseRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 认筹单(认筹记录表)  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-26
 */
@Service
public class TaRaiseRecordServiceImpl extends ServiceImpl<TaRaiseRecordMapper, TaRaiseRecord> implements ITaRaiseRecordService {

    private Logger logger = LoggerFactory.getLogger(TaRaiseRecordServiceImpl.class);

    @Autowired
    private TaRaiseRecordMapper taRaiseRecordMapper;

    @Override
    public ResponseBean listRaiseRecordByCondition(RaiseRecordRequestBO recordRequestBO, LocalDateTime startTime, LocalDateTime endTime, Integer pageNumber, Integer pageSize) {
        logger.info("TaRaiseRecordServiceImpl.listRaiseRecordByCondition 接收参数：bo:{},startTime:{},endTime:{},pageNumber:{},pageSize:{}", JSONObject.toJSONString(recordRequestBO),
                startTime, endTime, pageNumber, pageSize);

        ResponseBean responseBean = new ResponseBean();
        IPage<TaRaiseRecord> pg = new Page<>(pageNumber, pageSize);
        responseBean.addSuccess(taRaiseRecordMapper.listRaiseRecordByCondition(pg, recordRequestBO, startTime, endTime));
        return responseBean;
    }

    @Override
    public ResponseBean listRaiseOrderByCondition(RaiseOrderRequestBO orderRequestBO, LocalDateTime payStartTime, LocalDateTime payEndTime, Integer pageNumber, Integer pageSize) {
        logger.info("TaRaiseRecordServiceImpl.listOrderByCondition 接收参数：bo:{},startTime:{},endTime:{},pageNumber:{},pageSize:{}", JSONObject.toJSONString(orderRequestBO),
                payStartTime, payEndTime, pageNumber, pageSize);

        ResponseBean responseBean = new ResponseBean();
        IPage<TaRaiseRecord> pg = new Page<>(pageNumber, pageSize);
        responseBean.addSuccess(taRaiseRecordMapper.listRaiseOrderByCondition(pg, orderRequestBO, payStartTime, payEndTime));
        return responseBean;
    }
}
